@@ -1,4 +1,4 @@
-### Copyright (C) 2002-2004 Stephen Kennedy <stevek@gnome.org>
+### Copyright (C) 2002-2005 Stephen Kennedy <stevek@gnome.org>
 
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the GNU General Public License as published by
@@ -21,16 +21,15 @@ import os
 # gnome
 import gtk
 import gtk.glade
+import gobject
 
 # project
 import paths
 import prefs
 import gnomeglade
 import misc
-import melddoc
 import filediff
-import cvsview
-import svnview
+import vcview
 import dirdiff
 import task
 
@@ -45,7 +44,7 @@ for sourceview in "gtksourceview sourceview".split():
     except ImportError:
         pass
 
-version = "1.0.0"
+version = "1.1.2"
 
 # magic developer switch, changes some behaviour
 developer = 0
@@ -58,13 +57,13 @@ developer = 0
 
 class NewDocDialog(gnomeglade.Component):
 
-    TYPE = misc.struct(DIFF2=0, DIFF3=1, DIR2=2, DIR3=3, CVS=4, SVN=6)
+    TYPE = misc.struct(DIFF2=0, DIFF3=1, DIR2=2, DIR3=3, VC=4)
          
     def __init__(self, parentapp, type):
         self.parentapp = parentapp
         gnomeglade.Component.__init__(self, paths.share_dir("glade2/meldapp.glade"), "newdialog")
-        self._map_widgets_into_lists( ("fileentry", "direntry", "cvsentry", "svnentry", "three_way_compare", "tablabel") )
-        self.entrylists = self.fileentry, self.direntry, self.cvsentry, self.svnentry
+        self._map_widgets_into_lists( ("fileentry", "direntry", "vcentry", "three_way_compare", "tablabel") )
+        self.entrylists = self.fileentry, self.direntry, self.vcentry
         self.widget.set_transient_for(parentapp.widget)
         cur_page = type // 2
         self.notebook.set_current_page( cur_page )
@@ -92,8 +91,7 @@ class NewDocDialog(gnomeglade.Component):
                 paths.pop(0)
             methods = (self.parentapp.append_filediff,
                        self.parentapp.append_dirdiff,
-                       self.parentapp.append_cvsview,
-                       self.parentapp.append_svnview )
+                       self.parentapp.append_vcview )
             methods[page](paths)
         self.widget.destroy()
 
@@ -114,8 +112,8 @@ class ListWidget(gnomeglade.Component):
             rentext = gtk.CellRendererText()
             rentext.set_property("editable", 1)
             def change_text(ren, row, text):
-                iter = model.get_iter( (int(row),))
-                model.set_value( iter, colnum, text)
+                it = model.get_iter( (int(row),))
+                model.set_value( it, colnum, text)
                 self._update_filter_string()
             rentext.connect("edited", change_text)
             column = gtk.TreeViewColumn(label)
@@ -126,8 +124,8 @@ class ListWidget(gnomeglade.Component):
             model = view.get_model()
             rentoggle = gtk.CellRendererToggle()
             def change_toggle(ren, row):
-                iter = model.get_iter( (int(row),))
-                model.set_value( iter, colnum, not ren.get_active() )
+                it = model.get_iter( (int(row),))
+                model.set_value( it, colnum, not ren.get_active() )
                 self._update_filter_string()
             rentoggle.connect("toggled", change_toggle)
             column = gtk.TreeViewColumn(label)
@@ -143,14 +141,14 @@ class ListWidget(gnomeglade.Component):
         self._update_filter_model()
     def on_item_new_clicked(self, button):
         model = self.treeview.get_model()
-        iter = model.append()
-        model.set_value(iter, 0, "label")
-        model.set_value(iter, 2, "pattern")
+        it = model.append()
+        model.set_value(it, 0, "label")
+        model.set_value(it, 2, "pattern")
         self._update_filter_string()
     def _get_selected(self):
         selected = []
         self.treeview.get_selection().selected_foreach(
-            lambda store, path, iter: selected.append( path ) )
+            lambda store, path, it: selected.append( path ) )
         return selected
     def on_item_delete_clicked(self, button):
         model = self.treeview.get_model()
@@ -162,22 +160,22 @@ class ListWidget(gnomeglade.Component):
         for s in self._get_selected():
             if s[0] > 0: # XXX need model.swap
                 old = model.get_iter(s[0])
-                iter = model.insert( s[0]-1 )
+                it = model.insert( s[0]-1 )
                 for i in range(3):
-                    model.set_value(iter, i, model.get_value(old, i) )
+                    model.set_value(it, i, model.get_value(old, i) )
                 model.remove(old)
-                self.treeview.get_selection().select_iter(iter)
+                self.treeview.get_selection().select_iter(it)
         self._update_filter_string()
     def on_item_down_clicked(self, button):
         model = self.treeview.get_model()
         for s in self._get_selected():
             if s[0] < len(model)-1: # XXX need model.swap
                 old = model.get_iter(s[0])
-                iter = model.insert( s[0]+2 )
+                it = model.insert( s[0]+2 )
                 for i in range(3):
-                    model.set_value(iter, i, model.get_value(old, i) )
+                    model.set_value(it, i, model.get_value(old, i) )
                 model.remove(old)
-                self.treeview.get_selection().select_iter(iter)
+                self.treeview.get_selection().select_iter(it)
         self._update_filter_string()
     def on_items_revert_clicked(self, button):
         setattr( self.prefs, self.key, self.prefs.get_default(self.key) )
@@ -193,10 +191,10 @@ class ListWidget(gnomeglade.Component):
         model.clear()
         for filtstring in getattr( self.prefs, self.key).split("\n"):
             filt = misc.ListItem(filtstring)
-            iter = model.append()
-            model.set_value( iter, 0, filt.name)
-            model.set_value( iter, 1, filt.active)
-            model.set_value( iter, 2, misc.escape(filt.value))
+            it = model.append()
+            model.set_value( it, 0, filt.name)
+            model.set_value( it, 1, filt.active)
+            model.set_value( it, 2, misc.escape(filt.value))
    
 ################################################################################
 #
@@ -411,7 +409,7 @@ class MeldPreferences(prefs.Preferences):
         "edit_command_type" : prefs.Value(prefs.STRING, "internal"), #internal, gnome, custom
         "edit_command_custom" : prefs.Value(prefs.STRING, "gedit"),
         "supply_newline": prefs.Value(prefs.BOOL,1),
-        "text_codecs": prefs.Value(prefs.STRING, "utf8 latin1"), 
+        "text_codecs": prefs.Value(prefs.STRING, "utf8 latin1"),
         "save_encoding": prefs.Value(prefs.INT, 0),
         "draw_style": prefs.Value(prefs.INT,2),
         "toolbar_style": prefs.Value(prefs.INT,0),
@@ -422,7 +420,7 @@ class MeldPreferences(prefs.Preferences):
         "cvs_binary": prefs.Value(prefs.STRING, "/usr/bin/cvs"),
         "cvs_create_missing": prefs.Value(prefs.BOOL, 1),
         "cvs_prune_empty": prefs.Value(prefs.BOOL, 1),
-        "cvs_console_visible": prefs.Value(prefs.BOOL, 0),
+        "vc_console_visible": prefs.Value(prefs.BOOL, 0),
         "color_delete_bg" : prefs.Value(prefs.STRING, "DarkSeaGreen1"),
         "color_delete_fg" : prefs.Value(prefs.STRING, "Red"),
         "color_replace_bg" : prefs.Value(prefs.STRING, "#ddeeff"),
@@ -524,7 +522,7 @@ class MeldApp(gnomeglade.GnomeApp):
             self.toolbar_magic.hide()
         elif 1:
             def showPrefs(): PreferencesDialog(self)
-            gtk.idle_add(showPrefs)
+            gobject.idle_add(showPrefs)
         self.toolbar.set_style( self.prefs.get_toolbar_style() )
         self.prefs.notify_add(self.on_preference_changed)
         self.idle_hooked = 0
@@ -554,7 +552,7 @@ class MeldApp(gnomeglade.GnomeApp):
     def on_scheduler_runnable(self, sched):
         if not self.idle_hooked:
             self.idle_hooked = 1
-            gtk.idle_add( self.on_idle )
+            gobject.idle_add( self.on_idle )
 
     def on_preference_changed(self, key, value):
         if key == "toolbar_style":
@@ -602,6 +600,11 @@ class MeldApp(gnomeglade.GnomeApp):
     def on_menu_save_activate(self, menuitem):
         self.current_doc().save()
 
+    def on_menu_save_as_activate(self, menuitem):
+        pane = self.current_doc()._get_focused_pane()
+        if pane >= 0:
+            self.current_doc().save_file(pane, 1)
+
     def on_menu_refresh_activate(self, *args):
         self.current_doc().refresh()
 
@@ -622,6 +625,7 @@ class MeldApp(gnomeglade.GnomeApp):
         for c in self.notebook.get_children():
             c.get_data("pyobject").on_quit_event()
         self.quit()
+        return gtk.RESPONSE_CLOSE
 
     #
     # Toolbar and menu items (edit)
@@ -750,18 +754,11 @@ class MeldApp(gnomeglade.GnomeApp):
         else:
             self.append_filediff(paths)
 
-    def append_cvsview(self, locations):
+    def append_vcview(self, locations):
         assert len(locations) in (1,)
         location = locations[0]
-        doc = cvsview.CvsView(self.prefs)
-        self._append_page(doc, "cvs-icon.png")
-        doc.set_location(location)
-
-    def append_svnview(self, locations):
-        assert len(locations) in (1,)
-        location = locations[0]
-        doc = svnview.CvsView(self.prefs)
-        self._append_page(doc, "svn-icon.png")
+        doc = vcview.VcView(self.prefs)
+        self._append_page(doc, "vc-icon.png")
         doc.set_location(location)
 
     #
@@ -798,8 +795,8 @@ class MeldApp(gnomeglade.GnomeApp):
 usage_string = _("""Meld is a file and directory comparison tool. Usage:
 
     meld                        Start with no windows open
-    meld <dir>                  Start with CVS browser in 'dir'
-    meld <file>                 Start with CVS diff of 'file'
+    meld <dir>                  Start with VC browser in 'dir'
+    meld <file>                 Start with VC diff of 'file'
     meld <file> <file> [file]   Start with 2 or 3 way file comparison
     meld <dir>  <dir>  [dir]    Start with 2 or 3 way directory comparison
 
@@ -848,22 +845,16 @@ def main():
     elif len(args) == 1:
         a = args[0]
         if os.path.isfile(a):
-            if os.path.exists(os.path.join(os.path.dirname(a), '.svn')):
-                doc = svnview.CvsView(app.prefs)
-            else:
-                doc = cvsview.CvsView(app.prefs)
+            doc = vcview.VcView(app.prefs)
             def cleanup():
                 app.scheduler.remove_scheduler(doc.scheduler)
             app.scheduler.add_task(cleanup)
             app.scheduler.add_scheduler(doc.scheduler)
             doc.set_location( os.path.dirname(a) )
             doc.connect("create-diff", lambda obj,arg: app.append_diff(arg) )
-            doc.run_cvs_diff([a])
+            doc.run_diff([a])
         else:
-            if os.path.exists( os.path.join(a,".svn") ):
-                app.append_svnview( [a] )
-            else:
-                app.append_cvsview( [a] )
+            app.append_vcview( [a] )
                 
     elif len(args) in (2,3):
         app.append_diff(args)
